==> apache-paimon-0.6.1-incubating-src.tgz: paimon-0.6.1-incubating/paimon-spark/paimon-spark-common/src/test/scala/org/apache/paimon/spark/PaimonHiveTestBase.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.paimon.spark

import org.apache.paimon.hive.TestHiveMetastore
import org.apache.paimon.spark.extensions.PaimonSparkSessionExtensions

import org.apache.spark.SparkConf

class PaimonHiveTestBase extends PaimonSparkTestBase {

  protected lazy val testHiveMetastore: TestHiveMetastore = new TestHiveMetastore

  protected val hiveDbName: String = "test_hive"

  override protected def sparkConf: SparkConf = {
    super.sparkConf
      .set("spark.sql.warehouse.dir", tempDBDir.getCanonicalPath)
      .set("spark.sql.catalogImplementation", "hive")
      .set("spark.sql.catalog.spark_catalog", classOf[SparkGenericCatalog[_]].getName)
      .set("spark.sql.extensions", classOf[PaimonSparkSessionExtensions].getName)
  }

  override protected def beforeAll(): Unit = {
    testHiveMetastore.start()
    super.beforeAll()
    spark.sql(s"USE spark_catalog")
    spark.sql(s"CREATE DATABASE IF NOT EXISTS $hiveDbName")
    spark.sql(s"USE $hiveDbName")
  }

  override protected def afterAll(): Unit = {
    try {
      spark.sql(s"USE spark_catalog")
      spark.sql("USE default")
      spark.sql(s"DROP DATABASE $hiveDbName CASCADE")
    } finally {
      super.afterAll()
      testHiveMetastore.stop()
    }
  }

  override protected def beforeEach(): Unit = {
    spark.sql(s"USE spark_catalog")
  }

}

==> apache-paimon-0.7.0-incubating-src.tgz: paimon-0.7.0-incubating/paimon-spark/paimon-spark-common/src/test/scala/org/apache/paimon/spark/PaimonHiveTestBase.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.paimon.spark

import org.apache.paimon.hive.TestHiveMetastore

import org.apache.spark.SparkConf
import org.apache.spark.paimon.Utils

import java.io.File

class PaimonHiveTestBase extends PaimonSparkTestBase {

  protected lazy val tempHiveDBDir: File = Utils.createTempDir

  protected lazy val testHiveMetastore: TestHiveMetastore = new TestHiveMetastore

  protected val paimonHiveCatalogName: String = "paimon_hive"

  protected val hiveDbName: String = "test_hive"

  /**
   * Add spark_catalog ([[SparkGenericCatalog]] in hive) and paimon_hive ([[SparkCatalog]] in hive)
   * catalog
   */
  override protected def sparkConf: SparkConf = {
    super.sparkConf
      .set("spark.sql.warehouse.dir", tempHiveDBDir.getCanonicalPath)
      .set("spark.sql.catalogImplementation", "hive")
      .set("spark.sql.catalog.spark_catalog", classOf[SparkGenericCatalog[_]].getName)
      .set(s"spark.sql.catalog.$paimonHiveCatalogName", classOf[SparkCatalog].getName)
      .set(s"spark.sql.catalog.$paimonHiveCatalogName.metastore", "hive")
      .set(s"spark.sql.catalog.$paimonHiveCatalogName.warehouse", tempHiveDBDir.getCanonicalPath)
  }

  override protected def beforeAll(): Unit = {
    testHiveMetastore.start()
    super.beforeAll()
    spark.sql(s"USE spark_catalog")
    spark.sql(s"CREATE DATABASE IF NOT EXISTS $hiveDbName")
  }

  override protected def afterAll(): Unit = {
    try {
      spark.sql(s"USE spark_catalog")
      spark.sql("USE default")
      spark.sql(s"DROP DATABASE $hiveDbName CASCADE")
    } finally {
      super.afterAll()
      testHiveMetastore.stop()
    }
  }

  /** Default is spark_catalog */
  override protected def beforeEach(): Unit = {
    spark.sql(s"USE spark_catalog")
    spark.sql(s"USE $hiveDbName")
  }
}
